@@ -24,7 +24,7 @@ Ext.define('Ux.locale.override.extjs.Component', {
 
     setLocale : function(locale) {        
         var me          = this,
-            locales     = me.locales,
+            locales     = me.localesWin ? me.localesWin : me.locales,
             body        = locales.body,
             manager     = me.locale,
             defaultText = '',
